Eisenradio - a Web Radio expandable collection
==============================================

Designed to organize your web radios.

 * Radio Database with tools to delete and update, backup and restore
 * Style your app with pictures, write a comment or import a poem,
   song or study text to have a good time
 * A full-blown SVG animation to multiply your fun and energy usage
 * Create a shuffled playlist within a local audio files folder in seconds.
 * `Android apk package: download to mobile, rename *WHL to *ZIP, extract with
   Android file manager <https://pypi.org/project/eisenradio-apk/>`

The backend (Python) serves:
   * Front page as flask 'home' route
   * Tools and About pages as 'utils' route
   * Command line, grab radio streams and listen to one of them on the local HTTP proxy
   
Contents
========


.. toctree::
   :maxdepth: 2

   README
   overview
   features
   indexStructure
   sketch
   pipInstall
   knownProblems
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
